# User management

## Roles

Access to the address book is only granted after authentication. There
are three roles to authorize a user:

- ``visitor``: visit all person's data, search and export, change own password

- ``editor``: permissions of visitor and additionally edit all person's data,
  change own log-in name

- ``administrator``: permissions of editor and additionally create and change
  of address books, master data and users

## Create new users

Users are persons from the address book augmented by log-in information.

To create the first new user inside an address book the administrator has to log-in and then do the following:

1. Create a new person with an e-mail address using the ``Add person`` link.
2. Create a new user using ``Master data —> Users —> Add user``.

The newly created user has now a log-in (e-mail address) for the address book the person belongs to.
